@@ -1,5 +1,6 @@
 from .base_auth_flow import BaseAuthFlow
 from .client_credentials_flow import ClientCredentialsFlow
+from .oauth_flow import OauthFlow
 from .token import Token
 
-__all__ = [BaseAuthFlow, ClientCredentialsFlow, Token]
+__all__ = ["BaseAuthFlow", "ClientCredentialsFlow", "Token", "OauthFlow"]
